@@ -200,7 +200,7 @@ def worker_int(worker):
 
     ## get traceback info
     import threading, sys, traceback
-    id2name = dict([(th.ident, th.name) for th in threading.enumerate()])
+    id2name = {th.ident: th.name for th in threading.enumerate()}
     code = []
     for threadId, stack in sys._current_frames().items():
         code.append("\n# Thread: %s(%d)" % (id2name.get(threadId,""),
