@@ -1,10 +1,11 @@
 import cherrypy
 
+
+class Root(object):
+    @cherrypy.expose
+    def index(self):
+        return 'Hello World!'
+
 cherrypy.config.update({'environment': 'embedded'})
 
-class Root(object):
-    def index(self):
-        return 'Hello World!'
-    index.exposed = True
-
-app = cherrypy.Application(Root(), script_name=None, config=None)
+app = cherrypy.tree.mount(Root())
