@@ -3,7 +3,6 @@
 # This file is part of gunicorn released under the MIT license.
 # See the NOTICE for more information.
 
-import errno
 import os
 import sys
 from datetime import datetime
@@ -30,20 +29,6 @@ from gunicorn.workers.base_async import AsyncWorker
 VERSION = "gevent/%s gunicorn/%s" % (gevent.__version__, gunicorn.__version__)
 
 
-def _gevent_sendfile(fdout, fdin, offset, nbytes):
-    while True:
-        try:
-            return os.sendfile(fdout, fdin, offset, nbytes)
-        except OSError as e:
-            if e.args[0] == errno.EAGAIN:
-                socket.wait_write(fdout)
-            else:
-                raise
-
-def patch_sendfile():
-    setattr(os, "sendfile", _gevent_sendfile)
-
-
 class GeventWorker(AsyncWorker):
 
     server_class = None
@@ -52,9 +37,6 @@ class GeventWorker(AsyncWorker):
     def patch(self):
         monkey.patch_all()
 
-        # monkey patch sendfile to make it none blocking
-        patch_sendfile()
-
         # patch sockets
         sockets = []
         for s in self.sockets:
@@ -94,6 +76,8 @@ class GeventWorker(AsyncWorker):
             else:
                 hfun = partial(self.handle, s)
                 server = StreamServer(s, handle=hfun, spawn=pool, **ssl_args)
+                if self.cfg.workers > 1:
+                    server.max_accept = 1
 
             server.start()
             servers.append(server)
@@ -129,7 +113,7 @@ class GeventWorker(AsyncWorker):
             self.log.warning("Worker graceful timeout (pid:%s)" % self.pid)
             for server in servers:
                 server.stop(timeout=1)
-        except:
+        except Exception:
             pass
 
     def handle(self, listener, client, addr):
