@@ -3,13 +3,15 @@
 # This file is part of gunicorn released under the MIT license.
 # See the NOTICE for more information.
 
+import copy
 import os
 import sys
 
 try:
-    import tornado.web
+    import tornado
 except ImportError:
     raise RuntimeError("You need tornado installed to use this worker.")
+import tornado.web
 import tornado.httpserver
 from tornado.ioloop import IOLoop, PeriodicCallback
 from tornado.wsgi import WSGIContainer
@@ -17,6 +19,15 @@ from gunicorn.workers.base import Worker
 from gunicorn import __version__ as gversion
 
 
+# Tornado 5.0 updated its IOLoop, and the `io_loop` arguments to many
+# Tornado functions have been removed in Tornado 5.0. Also, they no
+# longer store PeriodCallbacks in ioloop._callbacks. Instead we store
+# them on our side, and use stop() on them when stopping the worker.
+# See https://www.tornadoweb.org/en/stable/releases/v5.0.0.html#backwards-compatibility-notes
+# for more details.
+TORNADO5 = tornado.version_info >= (5, 0, 0)
+
+
 class TornadoWorker(Worker):
 
     @classmethod
@@ -26,21 +37,20 @@ class TornadoWorker(Worker):
 
         def clear(self):
             old_clear(self)
-            self._headers["Server"] += " (Gunicorn/%s)" % gversion
+            if "Gunicorn" not in self._headers["Server"]:
+                self._headers["Server"] += " (Gunicorn/%s)" % gversion
         web.RequestHandler.clear = clear
         sys.modules["tornado.web"] = web
 
     def handle_exit(self, sig, frame):
         if self.alive:
-            super(TornadoWorker, self).handle_exit(sig, frame)
-            self.stop()
+            super().handle_exit(sig, frame)
 
     def handle_request(self):
         self.nr += 1
         if self.alive and self.nr >= self.max_requests:
-            self.alive = False
             self.log.info("Autorestarting worker after current request.")
-            self.stop()
+            self.alive = False
 
     def watchdog(self):
         if self.alive:
@@ -48,19 +58,59 @@ class TornadoWorker(Worker):
 
         if self.ppid != os.getppid():
             self.log.info("Parent changed, shutting down: %s", self)
-            self.stop()
+            self.alive = False
+
+    def heartbeat(self):
+        if not self.alive:
+            if self.server_alive:
+                if hasattr(self, 'server'):
+                    try:
+                        self.server.stop()
+                    except Exception:
+                        pass
+                self.server_alive = False
+            else:
+                if TORNADO5:
+                    for callback in self.callbacks:
+                        callback.stop()
+                    self.ioloop.stop()
+                else:
+                    if not self.ioloop._callbacks:
+                        self.ioloop.stop()
+
+    def init_process(self):
+        # IOLoop cannot survive a fork or be shared across processes
+        # in any way. When multiple processes are being used, each process
+        # should create its own IOLoop. We should clear current IOLoop
+        # if exists before os.fork.
+        IOLoop.clear_current()
+        super().init_process()
 
     def run(self):
         self.ioloop = IOLoop.instance()
         self.alive = True
-        PeriodicCallback(self.watchdog, 1000, io_loop=self.ioloop).start()
+        self.server_alive = False
+
+        if TORNADO5:
+            self.callbacks = []
+            self.callbacks.append(PeriodicCallback(self.watchdog, 1000))
+            self.callbacks.append(PeriodicCallback(self.heartbeat, 1000))
+            for callback in self.callbacks:
+                callback.start()
+        else:
+            PeriodicCallback(self.watchdog, 1000, io_loop=self.ioloop).start()
+            PeriodicCallback(self.heartbeat, 1000, io_loop=self.ioloop).start()
 
         # Assume the app is a WSGI callable if its not an
         # instance of tornado.web.Application or is an
         # instance of tornado.wsgi.WSGIApplication
         app = self.wsgi
-        if not isinstance(app, tornado.web.Application) or \
-           isinstance(app, tornado.wsgi.WSGIApplication):
+
+        if tornado.version_info[0] < 6:
+            if not isinstance(app, tornado.web.Application) or \
+            isinstance(app, tornado.wsgi.WSGIApplication):
+                app = WSGIContainer(app)
+        elif not isinstance(app, WSGIContainer):
             app = WSGIContainer(app)
 
         # Monkey-patching HTTPConnection.finish to count the
@@ -89,12 +139,24 @@ class TornadoWorker(Worker):
             server_class = _HTTPServer
 
         if self.cfg.is_ssl:
-            server = server_class(app, io_loop=self.ioloop,
-                    ssl_options=self.cfg.ssl_options)
+            _ssl_opt = copy.deepcopy(self.cfg.ssl_options)
+            # tornado refuses initialization if ssl_options contains following
+            # options
+            del _ssl_opt["do_handshake_on_connect"]
+            del _ssl_opt["suppress_ragged_eofs"]
+            if TORNADO5:
+                server = server_class(app, ssl_options=_ssl_opt)
+            else:
+                server = server_class(app, io_loop=self.ioloop,
+                                      ssl_options=_ssl_opt)
         else:
-            server = server_class(app, io_loop=self.ioloop)
+            if TORNADO5:
+                server = server_class(app)
+            else:
+                server = server_class(app, io_loop=self.ioloop)
 
         self.server = server
+        self.server_alive = True
 
         for s in self.sockets:
             s.setblocking(0)
@@ -107,15 +169,3 @@ class TornadoWorker(Worker):
         server.start(num_processes=1)
 
         self.ioloop.start()
-
-    def stop(self):
-        if hasattr(self, 'server'):
-            try:
-                self.server.stop()
-            except Exception:
-                pass
-        PeriodicCallback(self.stop_ioloop, 1000, io_loop=self.ioloop).start()
-
-    def stop_ioloop(self):
-        if not self.ioloop._callbacks and len(self.ioloop._timeouts) <= 1:
-            self.ioloop.stop()
