@@ -4,23 +4,13 @@
 # See the NOTICE for more information.
 
 import errno
-import sys
-
-try:
-    import unittest.mock as mock
-except ImportError:
-    import mock
+import unittest.mock as mock
 
 import gunicorn.pidfile
 
 
 def builtin(name):
-    if sys.version_info >= (3, 0):
-        module = 'builtins'
-    else:
-        module = '__builtin__'
-
-    return '{0}.{1}'.format(module, name)
+    return 'builtins.{}'.format(name)
 
 
 @mock.patch(builtin('open'), new_callable=mock.mock_open)
